c=======================================================================
c***********************************************************************
      subroutine cal_in
c***********************************************************************
c=======================================================================
      implicit none
c=======================================================================
c   this routine calculates the external conditions at an hourly
c   time step:
c 
c   temp   = air temperature (K);
c   hs     = air relative humidity;
c   apar   = absorbed irradiance at the leaf level 
c           (micromol m-2 s-1);
c   rbl    = aerodynamic + boundary layer resistance(m2 s /mol).
c=======================================================================

      include './com_18/parameter.common'
      include './com_18/climin.common'
      include './com_18/cstpi.common'
      include './com_18/day_corr.common'
      include './com_18/eco.common'
      include './com_18/ecoin.common'
      include './com_18/ecopro.common'
      include './com_18/envi.common'
      include './com_18/ext_con.common'
      include './com_18/ext_con2.common'
      include './com_18/gridin2.common'
      include './com_18/hcst.common'
      include './com_18/h2ocst.common'
      include './com_18/nspc.common'
      include './com_18/heure.common'
      include './com_18/laiste.common'
      include './com_18/radcst.common'
      include './com_18/rblcst1.common'
      include './com_18/res_par.common'
      include './com_18/sol_in.common'
      include './com_18/solpar.common'
      include './com_18/temper.common'
      include './com_18/varday.common'

c-----------------------------------------------
c JLP ajouté pour implicit none
c
      integer iday,ih,ip,irad,jday,jday2,jd,ndmean_t,ndmean_w
      
      real*4 arglog0,cdel,ch0,clcd,cte,facto,fdif,fexpo
      real*4 ftrsdif,ftrsdir,h0,ho1,hoo
      real*4 qh2o,rm,sdel,sl
      real*4 slsd,sth,temp2,tempi,th,theta
      real*4 tmin_day,tmax_day,xpar
      real*4 unitchg,us,us0,xls      
      
      
c------------------------------------------------  

      dimension tmin_day(ndy),tmax_day(ndy),xpar(ndy)


c=======================================================================
c   loops over the days
c=======================================================================

      do iday = 1, nd
         tmin_day(iday) = tcel(iday) - tdiff(iday) / 2.
         tmax_day(iday) = tcel(iday) + tdiff(iday) / 2.

c=======================================================================
c   calculation of the daily mean atmospheric pressure of h2o.
c=======================================================================

         tempi = tcel(iday) + temp0
         if(tcel(iday) .ge. 0.) then
            fexpo = ah2o/tempi + bh2o*log10(tempi) + ch2o
            qh2o = 10.**fexpo
         else
            facto = tcel(iday) * eh2o / tempi
            qh2o = dh2o * exp(facto)
         endif
         qh2o = qh2o * rhu(iday)

c=======================================================================
c   calculation of angles necessary in the atmospheric radiative
c   transfert scheme:
c
c   sdel  = sinus of the declinaison;
c   h0    = hourly angle of the day beginning;
c   ftrs  = atmospheric transmittance(dimensionless).
c=======================================================================

         sl    = pi365 * (iday - 79.092)
         if(sl .lt. 0.) sl = pi2 + sl
         th    = sl - xlsper
         sth   = sin(th)
         xls   = sl + sth*exc6 + sth*cos(th)*exc7
     &         + (3.*sth - 13.*sth*sth*sth/3.) * exc5
         theta = xls - xlsper
         rm    = (1. - exc4) / (1. + exc*cos(theta))
         sdel  = sin(obl) * sin(xls)
         cdel  = sqrt(1.-sdel*sdel)
         cte   = sunea / (rm * rm)
         slsd  = slati * sdel
         clcd  = clati * cdel
         ch0   = -slsd / clcd

         if(ch0 .ge. 1.) then
            h0     = 0.
         else
            if(ch0 .le. -1) then
               h0  = pi
            else
               h0  = acos(ch0)
            endif
         endif

         ftrsdir = ftrmax*sunhour(iday)
         ftrsdif = ftrmin*(1. - sunhour(iday))
         xpar(iday) = 0.
         partoc(iday) = 0.
         do ih = 1, nh2
           do ip = 1, npft
               do irad = 1,3
                  apar(ip,iday,ih,irad) = 0.
               enddo
           end do
         enddo
         do ih = 1, nh2
            do ip = 1, nplant
               fsun(ip,iday,ih)  = 0.
            end do
         enddo

c=======================================================================
c   rbl = aerodynamic (rae) + boundary layer (rbw) resitance
c   rae in s m-1
c   rbw in s m-1
c=======================================================================

         if(win(iday) .lt. 0.1 ) win(iday) = 0.1

         us0 = win(iday) * arbl

         do ip = 1, npft
            arglog0 = (zzra(ip) - disd(ip)) / z0vs(ip)
            us      = us0 / log(arglog0)
            rae(ip,iday) = win(iday) / (us*us)
            rbw(ip,iday) = brbl / (us**exrbl)
            unitchg = unitfac*(1.+(tcel(iday)/temp0))
     &               *patm0/patm
            rbl(ip,iday) = (rae(ip,iday) + h2osurco2*rbw(ip,iday)) 
     &                   * unitchg
         enddo

c=======================================================================
c   loops over the hours
c=======================================================================

         do ih = 1, nh2

c=======================================================================
c   temperature estimates
c   temp(iday,ih) = air temperature (K)
c=======================================================================

            temp(iday,ih)  = temp0+tcel(iday)+0.5
     &                      *tdiff(iday)*cohour(ih)

c=======================================================================
c   air relative humidity estimates. It is supposed that the
c   atmospheric water content is constant during the day.
c   qsatmb = saturation vapor pressure (mbar)
c=======================================================================

            temp2 = temp(iday,ih) - temp0
            if(temp2 .ge. 0.) then
               fexpo  = ah2o/temp(iday,ih)+bh2o*log10(temp(iday,ih))
     &                + ch2o
               qsatmb(iday,ih) = 10.**fexpo
            else
               facto  = temp2 * eh2o / temp(iday,ih)
               qsatmb(iday,ih) = dh2o * exp(facto)
            endif

            hs(iday,ih) = qh2o / qsatmb(iday,ih)
            if(hs(iday,ih) .gt. 1.) hs(iday,ih) = 1.
            if(hs(iday,ih) .lt. 0.) hs(iday,ih) = 0.

c=======================================================================
c   calculation of the solar irradiance at the earth surface
c   solg   = hourly value of the surface solar 
c            irradiance for the grid point studied
c           (w m-2);
c   xmucar = cosine of the solar zenithal angle , one 
c            value at each hour (dimensionless).
c=======================================================================

            xmucar(iday,ih) = 0.
            do irad = 1, 3
               par0(iday,ih,irad) = 0.
            enddo
            corr_hour(iday,ih) = 0.

            if(abs(hour2(ih)) .lt. h0) then
               if(abs(hour1(ih)) .le. h0) then

                  xmucar(iday,ih) = slsd + clcd * codelhour(ih)
                  corr_hour(iday,ih) = 1.

               else

                  ho1 = -h0
                  hoo = (hour2(ih) + ho1) / 2.
                  xmucar(iday,ih) = slsd + clcd 
     &                            * (sin(hour2(ih)) - sin(ho1))
     &                            / (hour2(ih)  - ho1)
                  if(xmucar(iday,ih).lt.0.) xmucar(iday,ih) = 0.
                  corr_hour(iday,ih) = (h0 - abs(hour2(ih))) / h_step 
                  if(corr_hour(iday,ih).lt.0. .or.
     &               corr_hour(iday,ih).gt.1.) then
                     write(61,*) 'error, hour cor:', iday,ih,
     &                            corr_hour(iday,ih)
                     write(61,*) 'h_step', h_step
                  stop
                  endif

               endif
               if(xmucar(iday,ih).lt.0.) then
                  write(61,*) 'error sun angle = ',xmucar(iday,ih),
     &            'hour = ',ih
                  stop
               endif

               fdif = 0.2
               par0(iday,ih,1) = cte * xmucar(iday,ih) * ftrmax 
     &                         * (1.-fdif) * 0.45
               par0(iday,ih,2) = cte * xmucar(iday,ih) * ftrmax 
     &                         * fdif * 0.45    ! old value: 0.45     
               par0(iday,ih,3) = cte * xmucar(iday,ih) * ftrmin * 0.55
            endif

c=======================================================================
c   dirrad = direct irradiance (w m-2);
c   difrad = diffuse irradiance (w m-2);
c=======================================================================

            xpar(iday) = xpar(iday) + corr_hour(iday,ih) *
     &                 ( par0(iday,ih,1) * sunhour(iday) 
     &                 + par0(iday,ih,2) * sunhour(iday)
     &                 + par0(iday,ih,3) * (1. -sunhour(iday)))

         enddo

         partoc(iday) = xpar(iday)
         xpar(iday) = xpar(iday) * parun

      enddo

c=======================================================================
c   minimum and maximum temperature, soil water content and day 
c   length for the ndmean previous days.
c=======================================================================

      do iday = 1, nd

         tmin2(iday)       = 0.
         tmax2(iday)       = 0.
         xpar2(iday)       = 0.
         water2(iday)      = 0.

         ndmean_t=4
         do jday = 1, ndmean_t
          jday2 = iday - jday
          if(jday2 .le. 0) jday2 = jday2 + nd
          tmin2(iday)  = tmin2(iday)  + tmin_day(jday2)/float(ndmean_t)
          tmax2(iday)  = tmax2(iday)  + tmax_day(jday2)/float(ndmean_t)
          xpar2(iday)  = xpar2(iday)  + xpar(jday2) /float(ndmean_t)
         end do

         ndmean_w=7
         do jday = 1, ndmean_w
          jday2 = iday - jday
          if(jday2 .le. 0) jday2 = jday2 + nd    
          water2(iday) = water2(iday) + water(jday2)/float(ndmean_w)
         enddo

      enddo
 
      return
      end subroutine cal_in