c=======================================================================
c***********************************************************************
      subroutine npp_cal(ngt,ny0,iread,itmt,tmt_it)
c***********************************************************************
c=======================================================================
      implicit none 
c=======================================================================
c
c   this routine calculates the net primary productivity and the
c   co2 carbon pools.
c
c   Plant are divided in 3 pools:
c       1 = "green biomass" including leaves (and active roots);
c       2 = rest of the plant
c       3 = reserve
c
c   Pool values are determined resolving the differential equations:
c
c      dC/dt = Fin - Fout
c      where C    = carbon pool (g m-2);
c            t    = time (day);
c            Fin  = incoming fluxes (g m-2 d-1) expressed as a  
c                   fraction of the total gpp except for "green 
c                   biomass for which Fin comes also from reserves in
c                   the growing season;
c            Fout = outgoing fluxes (g m-2 d-1) supposed proportional
c                   to carbon pools (k*C) except growing respiration 
c                   supposed equal to 0 when Fout > Fin and equal to
c                   h * dC/dt in other cases (h = 0.20).
c   Supposing that Fin and K are constant during a time step (here 
c   one day) the solution of this equation is:
c
c      C = C0 exp(-k*t/(1+h)) + {1 - exp(-k*t/(1_h))}*Fin/{(1+h)*k}
c          where C0 is the initial value of the pool.
c
c   carbon(ip,ipool,iday) = C.
c=======================================================================

      include './com_18/parameter.common'
      include './com_18/ageclas.common'
      include './com_18/annee.common'
      include './com_18/angppf.common'
      include './com_18/bagnum.common'
      include './com_18/biomasse.common'
      include './com_18/carbon_maxi.common'
      include './com_18/climin.common'
      include './com_18/cmoiRmin.common'
      include './com_18/coord.common'
      include './com_18/crops.common'
      include './com_18/cte.common'      
      include './com_18/day_corr.common'
      include './com_18/dayres.common'
      include './com_18/ecoin.common'
      include './com_18/ext_con.common'
      include './com_18/ext_con2.common'
      include './com_18/fire_emi.common'      
      include './com_18/fracc13.common'      
      include './com_18/gcaci2.common'
      include './com_18/gk.common'
      include './com_18/inidata.common'      
      include './com_18/lai.common'
      include './com_18/laih2o.common'
      include './com_18/laiste.common'
      include './com_18/loop.common'
      include './com_18/management.common'      
      include './com_18/mois.common'
      include './com_18/monthcst.common'
      include './com_18/nspc.common'
      include './com_18/number_year.common'
      include './com_18/pho_sch.common'
      include './com_18/plant_evol.common'      
      include './com_18/plant_pool.common'
      include './com_18/pnpp2.common'      
      include './com_18/radcst.common'
      include './com_18/res_par.common'
      include './com_18/res_temp2.common'
      include './com_18/strate.common'
      include './com_18/tresh.common'
      include './com_18/xvalues.common'
      include './com_18/frac_change.common'

      
      
c-----------------------------------------------
c JLP ajouté pour implicit none
c      
      integer , intent(in) :: ngt,ny0,iread,itmt
      integer ih,ipool,iday2,iday_sow,iharv
      real*4  , intent(in) :: tmt_it
      real*4  faparl,tot_frac,faparh
c------------------------------------------------      

c   second argument of year_iteration : 
c   tree  = 0
c   grass = 1
c-----------------------------------------------------------------------

c=======================================================================
c     crops 
c=======================================================================

      nstrate = 0
      ipi = npft0+1
      ipf = npft0+ncrop

c=======================================================================
c     limite the lai due to water fluxes.. CARAIB and IBM have to be
c     coherent
c=======================================================================

cIngrid2018
      call wat_limit

c=======================================================================
c     carbon fluxes calulation
c=======================================================================

      call year_iteration(ngt,itmt,tmt_it)

cIngrid2018
      call lai_limit_w

c=======================================================================
c     pastures 
c=======================================================================

      nstrate = 0
      ipi = npft0+ncrop+1
      ipf = npft0+ncrop+npast

c=======================================================================
c     limite the lai due to water fluxes.. CARAIB and IBM have to be
c     coherent
c=======================================================================

cIngrid2018
      call wat_limit

c=======================================================================
c     carbon fluxes calulation
c=======================================================================

      call year_iteration(ngt,itmt,tmt_it)

cIngrid2018
      call lai_limit_w

c=======================================================================
c     trees
c=======================================================================

      nstrate = 0
      ipi = nherb+nbush+1
      ipf = npft0

c=======================================================================
c     limits the lai due to water fluxes.. CARAIB and IBM have to be
c     coherent
c=======================================================================

cIngrid2018
      call wat_limit

c=======================================================================
c     carbon fluxes calulation
c=======================================================================

      call year_iteration(ngt,itmt,tmt_it)

cIngrid2018
      call lai_limit_w

      if (ifrac.eq.1 .and.ny0.eq.1 .and. nyear.eq.1 .and. iread.eq.0
     &   .and. ifrac_rd.eq.0) 
     &   call frac_trees(ngt)

c=======================================================================
c     herbs and shrubs
c=======================================================================

      call solar_trees(ngt)

      nstrate = 1
      ipi = 1
      ipf = nherb+nbush

c=======================================================================
c     limits the lai according to water fluxes.. CARAIB and IBM have to 
c     be coherent
c=======================================================================

cIngrid2018
      call wat_limit

c=======================================================================
c     carbon fluxes calulation
c=======================================================================

      call year_iteration(ngt,itmt,tmt_it)

cIngrid2018
      call lai_limit_w

      if (ifrac.eq.1 .and. ny0.eq.1 .and. nyear.eq.1 .and. iread.eq.0
     &   .and. ifrac_rd.eq.0) 
     &   call frac_herbs(ngt)

c=======================================================================
c   yearly gpp and fractionation calculation
c=======================================================================
      do ip = 1,npft 
        iharv = 0     
        if(frac(ip).gt.1.e-7) then
          do iday = 1, nd
            if(ip.le.npft0.or.ip.ge.npft0+ncrop+1) then
              ygppf(ip) = ygppf(ip) + xgpp(ip,iday)
	      ygppf_ini(ip,ngt) = ygppf(ip)  
	    else
              if(iharv.eq.0) then
	        ygppf(ip) = ygppf(ip) + xgpp(ip,iday)
		if(maturity(ip).eq.-999) ygppf(ip) =0.
		ygppf_ini(ip,ngt) = ygppf(ip)
                if(iphase(ip,iday).eq.2) then
	          ygppf_ini(ip,ngt) = 0.
	          iharv = 1
	        endif  
	      else 
	        ygppf_ini(ip,ngt) = ygppf_ini(ip,ngt) + xgpp(ip,iday)
	      endif   
	    endif 	    
            yfractf(ip) = yfractf(ip) + xfract(ip,iday)
          enddo
          if (ygppf(ip).eq.0.) then 
            yfractf(ip) = 0. 
          else
            yfractf(ip) = yfractf(ip) / ygppf(ip)
          endif
        endif
      end do
      

c=======================================================================
c      fire module
c=======================================================================

      call fire(ngt)

c=======================================================================
c      mortality calculation
c=======================================================================

      call mortality(ngt)

c=======================================================================
c      biomass correction module
c=======================================================================

      call biomass_correction 



c=======================================================================
c   grid point gpp, npp, lai, biomass, 13C fract and fire emission
c=======================================================================

      do iday = 1, nd
        iday2 = iday-1
	if(iday .eq. 1) iday2 = nd
        do ip = 1, npft
          xdgpp(iday) = xdgpp(iday) + frac(ip) * xgpp(ip,iday)
          xdnpp(iday) = xdnpp(iday) + frac(ip) * xnpp(ip,iday)
          xdlai(iday) = xdlai(iday) + frac(ip) * xlai(ip,iday)
          xdfract(iday) = xdfract(iday) 
     &                              + frac(ip) * xfract(ip,iday)
          do ipool = 1, npool 
           xdbiom(iday) = xdbiom(iday) + frac(ip)*carbon(ip,ipool,iday)   
           ybiomf(ip) = ybiomf(ip) + carbon(ip,ipool,iday)/float(nd)
	   xemifire(ip,iday) = xemifire(ip,iday)
     &                       + emi_burn_veg(ip,ipool,iday)
	   xcharvest(ip,iday) = xcharvest(ip,iday)
     &                       + charvest(ip,ipool,iday)     
           yemifiref(ip) = yemifiref(ip) + emi_burn_veg(ip,ipool,iday)
          enddo
	  
	  if(ip.le.npft0.or.ip.ge.npft0+ncrop+1) then
	    ybiomag(ip) = ybiomag(ip) 
     &	     + (carbon(ip,1,iday)
     &        + carbon(ip,2,iday)-root_biomass(ip,iday))/float(nd)
            ybiombg(ip) = ybiombg(ip)+root_biomass(ip,iday)/float(nd)
c Ingrid
	    ybiomtot(ip) = carbon(ip,1,iday)+carbon(ip,2,iday)
          else
	    if (iphase(ip,iday2).eq.1.and.iphase(ip,iday).eq.2) then
	      if(iday.eq.1) then
	        root_biomass(ip,iday2) = root_ini(ip)
                carbon(ip,1,iday2) = ycar_ini(ip,1,ngt) !carbon_ini(ip,1)
		carbon(ip,2,iday2) = ycar_ini(ip,2,ngt) !carbon_ini(ip,2)
	      endif	
	      ybiomag(ip) = carbon(ip,1,iday2)
     &        + carbon(ip,2,iday2)-root_biomass(ip,iday2)
              ybiombg(ip) = root_biomass(ip,iday2)
c Ingrid
	      ybiomtot(ip) = carbon(ip,1,iday2) + carbon(ip,2,iday2)
            endif
	  endif  	  
c Ingrid
        yield(ip)=yield_fac(ip)*ybiomtot(ip)

        enddo



        if(xdgpp(iday).ne.0.) then
          xdfract(iday) = xdfract(iday) / xdgpp(iday)
        else
          if(abs(xdfract(iday)).gt.1.e-20) then
            write(61,*) 'error, fractionation:',iday,xdfract(iday),
     &                  xdgpp(iday)
          endif
	  xdfract(iday) = 0.
        endif

      enddo

c=======================================================================
c    vegetation fraction calculation. It is used to normalize FAPAR
c=======================================================================

      tot_frac = 0.
      do ip = 1, npft
        tot_frac = tot_frac + frac(ip)
      end do

c      write(*,*)'npp_cal:after loop iday,ip, ybiom'
c=======================================================================
c   fapar calculation
c=======================================================================

      do iday = 1, nd
       xdfapar(iday) = 0.
       if(partoc(iday).gt.0.) then
         do ip = 1, npft
           faparl = 0.
           if(frac(ip) .gt. 1.e-7) then
             do ih = 1, nh2
               faparh = 0.

                 faparh = faparh
     &   + (sunhour(iday) * (fsun(ip,iday,ih)*apar(ip,iday,ih,1)
     &   + (1.-fsun(ip,iday,ih))*apar(ip,iday,ih,2))
     &   + (1.-sunhour(iday)) * apar(ip,iday,ih,3))
     &   *corr_hour(iday,ih)/radun

               faparl = faparl + faparh
             enddo
             faparl = faparl * xlai(ip,iday) * frac(ip)
           endif
           xdfapar(iday) = xdfapar(iday) + faparl
         enddo
         xdfapar(iday) = xdfapar(iday) / partoc(iday)

         if(tot_frac.gt.0.0) then
           xdfapar(iday)= xdfapar(iday) / tot_frac
         endif
       endif
       if(xdfapar(iday).lt.0. .or. xdfapar(iday).gt.1.) then
         write(61,*) 'error L',iday,xdfapar(iday)
       endif
      enddo

c      write(*,*)'npp_cal:after loop iday fapar'

c=======================================================================
c   calculation of g*Ca and g*Ci
c=======================================================================

      do iday = 1, nd
        do ip = 1, npft

            xdgca(iday) = xdgca(iday) 
     &                  + gca(ip,iday) * xlai(ip,iday) * frac(ip)
            xdgci(iday) = xdgci(iday) 
     &                  + gci(ip,iday) * xlai(ip,iday) * frac(ip)
        enddo
      enddo

c      write(*,*)'npp_cal: end of subroutine'


      return
      end subroutine npp_cal