c=======================================================================
c***********************************************************************
      subroutine set_frac(ngt)
c***********************************************************************
c=======================================================================

c=======================================================================
c     This routine reads the different environmental inputs as well
c     as vegetation characteristics and sets them in the right form.
c=======================================================================

      implicit none

      include './com_18/parameter.common'
      include './com_18/annee.common'
      include './com_18/climin0.common'
      include './com_18/climkop.common'
      include './com_18/coord.common'
      include './com_18/cstpi.common'
      include './com_18/cte.common'
      include './com_18/eco.common'
      include './com_18/ecoin.common'
      include './com_18/ecopro.common'
      include './com_18/envi.common'
      include './com_18/fgr.common'
      include './com_18/frac_change.common'      
      include './com_18/gridclim.common'
      include './com_18/griddata.common'
      include './com_18/gridin2.common'
      include './com_18/input_par.common'
      include './com_18/inidata.common'
      include './com_18/landuse.common'      
      include './com_18/nspc.common'
      include './com_18/prev_yr.common'      
      include './com_18/radcst.common'
      include './com_18/smrd.common'
      include './com_18/sr_par.common'
      include './com_18/temper.common'
      include './com_18/vegfr.common'
      include './com_18/xlaic.common'
 
      real*4 plant_lai, plant_fgrn, frc_tree
      real*4 frc_trbsh
c-----------------------------------------------
c JLP ajouté pour implicit none
c
      integer , intent(in) :: ngt
      
      integer ip,k
      real*4 err,permdpt,ta_yr

c------------------------------------------------  

c=======================================================================
c This subroutine sets vegetation fraction, LAI, albedo and emissivity
c parameters, rooting depth and fsi,fci,wpi for IBM
c=======================================================================

c=======================================================================
c   sets vegetation fraction cover and LAI
c   frac(ip): vegetation fraction in each storey
c   frc(ip): fractional cover of vegetation class ip
c   fveg: fractional vegetation cover 
c=======================================================================
      do ip = 1, npft
        frac(ip) = yfrac_ini(ip,ngt)
        xlmin(ip) = ylaimin_ini(ip,ngt)
        xlmax(ip) = ylaimax_ini(ip,ngt)
        plant_lai = ylaimax_ini(ip,ngt)
        call fgrn_calc(plant_lai,plant_fgrn) 
        fgrnmax(ip) = plant_fgrn 
	xlaimax_prv(ip) = ylaimax_ini(ip,ngt)       
      end do

      do ip = npft0+1, npft
        frc(ip) = fgrnmax(ip)*frac(ip)
      end do

      frc_tree = 0.
      do ip = nherb+nbush+1, npft0
        frc(ip) = fgrnmax(ip)*frac(ip)
        frc_tree = frc_tree+frc(ip)
      end do
      if (frc_tree.gt.frac_nat(ngt)) frc_tree = frac_nat(ngt)

      do ip = 1, nherb+nbush 
        frc(ip) = (frac_nat(ngt)-frc_tree)*fgrnmax(ip)*frac(ip)
      end do

       fveg=0.
       do ip =1,npft
          fveg = fveg+frc(ip)
       enddo
       
       frc_trbsh=0.
       do ip =nherb+1,npft0
          frc_trbsh = frc_trbsh+frc(ip)
       enddo

       if(fveg.gt.1.) then
          err = fveg-1.
           if(err.gt.0.03)then
            write(61,*) 'Error fveg:', fveg,ylongi,ylati
            stop
           endif          
          do ip=1,npft
             frc(ip) = frc(ip)/fveg
          enddo
          fveg=1.
       elseif(fveg.lt.0.) then
          write(61,*) 'Error fveg:', fveg,ylongi,ylati
          stop
       endif

c   albv: albedo of vegetation cover
c   emiv: emissivity of vegetation cover
c  ---------------------------------------------------------------------
       albv=0.
       albwd=0.
       emiv=0.
       if(fveg.gt.0.)then
         do ip=1,npft
           albv = albv + 0.5 * (alvsw(ip)+alvlw(ip))
     1                * frc(ip)/fveg

           emiv = emiv + emv(ip)*frc(ip)/fveg
         enddo
c         do ip = nherb+nbush+1, npft0
c
c           albwd = albwd + alvwd(ip)*frc(ip)/frc_tree
c     
c         enddo
       else
         albv=0.20
         emiv=0.97
       endif

c       if(frc_tree.gt.0.)then
       if(frc_trbsh.gt.0.)then
c         do ip = nherb+nbush+1, npft0
         do ip = nherb+1, npft0


c           albwd = albwd + alvwd(ip)*frc(ip)/frc_tree
           albwd = albwd + alvwd(ip)*frc(ip)/frc_trbsh
     
         enddo
	else
	 albwd=0.12
       endif
	

c=======================================================================
c   sdens : Density of soil mineral particles (g m-3) (not used)
c   rootd : Rooting depth (mm)
c   fsi   : Water saturation (mm) 
c   fci   : Field capacity (mm) 
c   wpi   : Wilting point (mm)
c=======================================================================

c      sdens=(cla*2.52+sil*2.60+san*2.8) * 1.d+6

      if(isunit.eq.4)then
c  lithosol: by convention rootd = 100 mm 
c  ---------------------------------------------------------------------
        rootd=500.
      else
c  rooting depth: calculated on vegetated fraction only
c  ---------------------------------------------------------------------
         if(fveg.gt.0.)then
            rootd = 0.
            do ip = 1, npft
               rootd = rootd+frc(ip)*rdveg(ip)/fveg
            enddo
         else
            rootd = 500.
         endif
      endif
         
c  correction of rooting depth for permafrost
c  rooting depth set to 580 mm in permafrost regions
c  ---------------------------------------------------------------------
          
      ta_yr = 0.
      permdpt = 580.
      do k =1,nm
         ta_yr=ta_yr+tcelkop(k)/float(nm)
      enddo

      drn_fac = 1.
      if (ta_yr.lt.0.) then
         if (rootd.gt.permdpt) rootd=permdpt
         drn_fac = 0.1
      endif

c=======================================================================
c     saturation, field capacity and wilting point (mm)
c=======================================================================

      fsi=smfs*rootd
      fci=smfc*rootd
      wpi=smwp*rootd


      return
      end subroutine set_frac