c=======================================================================
c***********************************************************************
      subroutine daily_weather(ngt,iread)
c***********************************************************************
c=======================================================================

c=======================================================================
c     This routine estimates daily weather data from monthly values.
c=======================================================================
      IMPLICIT NONE
      
      include './com_18/parameter.common'
      include './com_18/acclim.common'      
      include './com_18/burned.common'
      include './com_18/climin0.common'
      include './com_18/climin.common'
      include './com_18/coord.common'
      include './com_18/cte.common'
      include './com_18/crops.common'
      include './com_18/gddpix.common'
      include './com_18/gene.common'
      include './com_18/iprt.common'
      include './com_18/monthcst.common'
      include './com_18/nspc.common'
      include './com_18/prt_ctrl.common'
      include './com_18/pzone.common'
      include './com_18/snow.common'
      include './com_18/temper.common'

      integer ngt,iread
      integer m2,iy_past
      real*4 ytem

c-----------------------------------------------
c JLP ajout� pour implicit none
c
      integer iday,im,jday,m,num2
      real*4  ccd,cci,ccm,ccw,had,ham,haw,omcc,omha,ppmth,regres,tddmax
     &      ,tdmax,tdnmin,tmmax,tnight,tnoon
c
c-----------------------------------------------

      omcc = 0.8
      omha = 0.8

c=======================================================================
c   calculation of daily values:
c
c   * precipitation, temperature and temperature daily range are
c     stochasticaly generated;
c   * sunshine hours and relative humidity variate between 2
c     values; one for raining days and one for the other days;
c   * wind speed, soil water content and snow cover fraction are
c     linearly related to monthly data.
c=======================================================================

      Tdmin = 100.
      Tdmax = -100.
      Tdnmin = 100.
      Tddmax = -100.
c      Tc   = 100.
c      Tc01 = 100.
c      Tc02 = 100.
c      Tc03 = 100.
c      Tc04 = 100.
c      Tc05 = 100.
c      Tc06 = 100.
c      Tc07 = 100.
c      Tc08 = 100.
c      Tc09 = 100.
c      Tc10 = 100.
c      Tc11 = 100.
c      Tc12 = 100.
      gdd0 = 0.
      gdd5 = 0.
      
      ytem = 0.
      

      do iday = 1, nd
         m = imonth(iday)

c   in southern hemisphere a dephasing of six months is applied,
c   i.e. the statistics of July is adopted for January, that of
c   August for February, etc
c----------------------------------------------------------------------

         jday = iday
         if(ylati.lt.0.)then
            if(iday.le.181)then
               jday=iday+184
            else
               jday=iday-181
            endif
         endif
         if (idaily_in.eq.0) then
          prc(iday)   = prc0(m)         * rapportP(izonepxl,jday)
          tcel(iday)  = (tcel0(m)+temp0)* rapportT(izonepxl,jday)-temp0
          tdiff(iday) = tdiff0(m)       * rapportDT(izonepxl,jday)
         endif
         
         if (tcel(iday).lt.Tdmin) Tdmin = tcel(iday)
         if (tcel(iday).gt.Tdmax) Tdmax = tcel(iday)
         if ((tcel(iday)-tdiff(iday)/2.).lt.Tdnmin)
     &        Tdnmin = tcel(iday)-tdiff(iday)/2.
         if ((tcel(iday)+tdiff(iday)/2.).gt.Tddmax)
     &        Tddmax = tcel(iday)+tdiff(iday)/2.


         if (tcel(iday).gt.0.) gdd0 = gdd0 + tcel(iday)
         if (tcel(iday).gt.5.) gdd5 = gdd5 + (tcel(iday)-5.)


c=======================================================================
c   Traitement de la couverture nuageuse et de l'humidite relative
c   Ces variables sont plus elevees les jours de pluie que les
c   jours secs. La moyenne mensuelle est respectee
c=======================================================================

         if (idaily_in.eq.0) then
         
          ccm = 1.-sunhour0(m)
          ham = rhu0(m)

          if(ylati.ge.0.)then
            ppmth = float(nombrejp(izonepxl,m))/float(mlength(m))
          else
            ppmth = float(nombrejpS(izonepxl,m))/float(mlength(m))
          endif

          if (ppmth.ne.0.) then

            ccd = (ccm-ppmth*omcc)/(1.-ppmth*omcc)
            if(ccd.lt.0.)ccd=0.
            if(ccd.gt.1.)ccd=1.
            ccw = (ccm - (1.-ppmth)*ccd)/ppmth
            had = (ham-ppmth*omha)/(1.-ppmth*omha)
            if(had.lt.0.1)then
               had=0.1
               if(had.gt.ham)ham=had
            endif
            if(had.gt.1.)had=1.
            haw = (ham - (1.-ppmth)*had)/ppmth

          else

            ccd = ccm
            ccw = ccm
            had = ham
            haw = ham

          endif

          if(prc(iday).gt.1.e-20)then
            cci = ccw
            rhu(iday) = haw
          else
            cci = ccd
            rhu(iday) = had
          endif

          sunhour(iday) = 1.-cci
          if(sunhour(iday).lt.0.)sunhour(iday)=0.
          if(sunhour(iday).gt.1.)sunhour(iday)=1.
        
         endif
         
c=======================================================================

         if(iday.eq.numday(m)) then
            if (idaily_in.eq.0) win(iday) = win0(m)
            xl_flash(iday) = xmflash(m)
         else
            if(iday.lt.numday(m)) m2 = m - 1
            if(iday.gt.numday(m)) m2 = m + 1
            if(m2.eq.0) then
               m2 = nm
               num2 = numday(m2) - nd
            elseif(m2.eq.nm+1) then
               m2 = 1
               num2 = numday(m2) + nd
            else 
               num2 = numday(m2)
            endif
            regres = float(iday - numday(m)) / float(num2 - numday(m))
            if (idaily_in.eq.0) then
             win(iday)   = win0(m) + (win0(m2) - win0(m)) * regres
            endif
            if (ifire.eq.1) then
             xl_flash(iday)=xmflash(m)+(xmflash(m2)-xmflash(m))*regres
            endif
         endif
c----------------------------------------------------------------------
c  Annual mean temperature (for acclimation)
         ytem = ytem+tcel(iday)/float(nd)


      enddo
      
c  records annual mean temperature in ytem_prev
c 
      if ((nyear.eq.1).and.(iread.eq.0)) then
        do iy_past = 1, 5 
         ytem_prev(ngt,iy_past) = ytem 
	end do
	do im = 1, nm
	 py_mtem(ngt,im) = tcel0(im)
	end do 
      else        
        do iy_past = 5, 2, -1 
         ytem_prev(ngt,iy_past) = ytem_prev(ngt,iy_past-1)
	end do
	ytem_prev(ngt,1) = ytem
      endif
c----------------------------------------------------------------------


      Tmmin = 1000.
      Tmmax = -1000.
      do im = 1, nm
c   Attention: night temperature for Tmmin (standard version)
c              daily mean temperature for this version           
c----------------------------------------------------------------------
c         Tnight=tcel0(im)-0.5*tdiff0(im)
         Tnight=tcel0(im)
         Tnoon=tcel0(im)+0.5*tdiff0(im)
         if (Tnight.le.Tmmin) then
            Tmmin = Tnight
         endif
         if (Tnoon.ge.Tmmax) then
            Tmmax = Tnoon
         endif
      enddo
                    

      if (iyprt.ge.1) then
       if(iprt_Tdmin.eq.1) 
     &    write(70,100) ylongi,ylati,Tdmin,Tdmax,Tdnmin,Tddmax
       if(iprt_Tmmin.eq.1) write(71,100) ylongi,ylati,Tmmin,Tmmax
       if(iprt_gdd.eq.1)   write(72,200) ylongi,ylati,gdd0,gdd5
      endif

 100  format(2(f8.3,1x),4(f8.2,1x))
 200  format(2(f8.3,1x),2(f8.2,1x))
 
      return
      end subroutine daily_weather