c=======================================================================
c***********************************************************************
      subroutine nonlineq2(xa,xb,nint,x,fx,ermax,nitmax,imeth,num,ngt)
c***********************************************************************
c=======================================================================      

c   Subroutine nonlineq solves a non linear equation of the type:
c           f(x) = 0
c   by the bisection method or the "regula falsi" method.
c   It calls the user-defined subroutine "funcx(x,fx)" which
c   define the f(x) function. 
c
c      xa = lower bound of interval in which the solution is 
c           searched for
c      xb = upper bound of interval in which the solution is 
c           searched for
c      nint = number of intervals into which [xa,xb] is divided
c           when searching for a (smaller) interval of changing
c           sign (e.g. 10)
c      x = - at entry, x is set to any value between a and b;
c            it may represent an "initial guess" of the solution
c          - at exit, x contains the estimated value of the zero 
c            of the function 
c      fx = at output, fx contains f(x), i.e. fx should be close to
c           0, if x contains a good evaluation of the zero
c      ermax = maximum acceptable error on fx, 
c               i.e., when (abs(fx).le.ermax) the zero is accepted
c      nitmax = maximum number of iterations allowed (e.g., 100)
c      imeth = flag to select resolution method. Set imeth to 0 for
c              bisection method and to 1 for "regula falsi"
c      num = at exit, contains total number of iterations performed
c   
c   The variable "precmc" below must be set to a small number
c   representing machine precision. The relative error on the
c   zero (x) cannot be smaller than precmc. With single precision
c   a value of precmc of 1.e-6 is recommended. For double precision
c   a value as small as 1.d-12 can be used.
c-------------------------------------------------------------------   
c -- JLP      implicit double precision (a-h,o-z)
      implicit none
      
      include './com_18/parameter.common'
      include './com_18/cte.common'
      include './com_18/kernel.common'
c-----------------------------------------------
c JLP ajout� pour implicit none
c
      integer k,nit
      real*8  delx,err,errx,fx1,fx2,precmc,prod,prod1,residu,x_old,x1,x2
c
c-----------------------------------------------      
      integer nint,nitmax,imeth,num,ngt
      real*4 xa,xb,ermax
      real*8 x,fx

      precmc = 1.d-12

      num = 0

      delx = (xb-xa)/float(nint)

c--------------------------------------------------------------
c   initial try with previous value of x and values smaller or 
c   larger by an amount delx 
c   (sets values for x1 and x2 with fx1*fx2 < 0)
c--------------------------------------------------------------
      
      call funcx2(x, fx)
C      write(*,*)'x:',x,' fx:',fx
      
      if(x.ge.-1.e-2.and.x.le.1.e-2) go to 400
c      if(x.ge.-1.e-3.and.x.le.1.e-3) go to 400 !picea

      err = abs(fx)
      if (err.le.ermax) go to 300            

      x1 = x 
      fx1 = fx

      x = x1+delx
      if (x.gt.xb) x=xb
      if (x.lt.xa) x=xa

      num = num + 1
      call funcx2(x, fx)
c      write(*,*)'x:',x,' fx:',fx

      if(x.ge.-1.e-2.and.x.le.1.e-2) go to 400
c      if(x.ge.-1.e-3.and.x.le.1.e-3) go to 400

      prod = fx*fx1
      if (prod.gt.0) then
         x = x1-delx
         if (x.gt.xb) x=xb
         if (x.lt.xa) x=xa
         call funcx2(x, fx)
c         write(*,*)'x:',x,' fx:',fx

         if(x.ge.-1.e-2.and.x.le.1.e-2) go to 400
c         if(x.ge.-1.e-3.and.x.le.1.e-3) go to 400       
         prod1 = fx*fx1
         if (prod1.le.0) then
            x2 = x
            fx2 = fx
            go to 200
         endif
      else
         x2 = x
         fx2 = fx
         go to 200
      endif

c--------------------------------------------------------------
c   if initial try fails, search for the solution over the  
c   entire range xa to xb 
c--------------------------------------------------------------

      x = xa

      num = num + 1
      call funcx2(x, fx)
c      write(*,*)num,'  x:',x,' fx:',fx
      if(x.ge.-1.e-2.and.x.le.1.e-2) go to 400
c      if(x.ge.-1.e-3.and.x.le.1.e-3) go to 400

      x1 = x
      fx1 = fx
           

      do k = 1, nint
       x = xa+delx*float(k)
       num = num + 1

       call funcx2(x, fx)
c       write(*,*)'x:',x,' fx:',fx
       
       if(x.ge.-1.e-2.and.x.le.1.e-2) go to 400
c       if(x.ge.-1.e-3.and.x.le.1.e-3) go to 400

       prod = fx1*fx
       if (prod.gt.0.) then
         x1 = x 
         fx1 = fx 
       else
         x2 = x
         fx2 = fx
         go to 200
       endif 

      end do

c      write(*,*)'No solution found for x between xa and xb'
C      write(*,*)' x=',x,' fx=',fx
C      write(*,*)'program stop'
      go to 400 !pas dans fagus ???
C      stop     

c--------------------------------------------------------------
c   after finding two values of x with fx of different signs,
c   we solve the equation by bisection (imeth=0) or "regula falsi" 
c   (imeth=1) method  
c--------------------------------------------------------------
      
 200  continue

      
c      write(*,*)'Interval of changing sign found'

      do nit = 1, nitmax

       num = num + 1

       x_old = x

       if (imeth.eq.0) then
         x = (x1+x2)/2.         
        else
         residu = -fx1*(x2-x1)/(fx2-fx1)
         x = x1 + residu
       endif

       call funcx2(x, fx)

       err=abs(fx)
c       write(*,*)num,'  x:',x,' fx:',fx

       if(x.ne.0.) then 
          errx = abs((x-x_old)/x)
         else
          errx = abs(x-x_old)
       endif
       if ((err.le.ermax).or.(errx.le.precmc)) go to 300

       prod = fx*fx2
       if (prod.gt.0) then
         x2 = x
         fx2 = fx
       else
         x1 = x
         fx1 = fx
       endif
       
      end do

      write(*,*)'Too much iterations in subroutine nonlineq'
      write(*,*)'num=',num,' x=',x
      write(*,*)'fx=',fx
      write(*,*)'program stop'
      stop
      
 400  continue
      
      x = -999999.     

 300  continue


      return
      end subroutine nonlineq2