c=======================================================================
c***********************************************************************
      subroutine read_in(ngt,iread)
c***********************************************************************
c=======================================================================

c=======================================================================
c     This routine reads the different environmental inputs as well
c     as vegetation characteristics and set them in the right form.
c=======================================================================

      USE MOD_NETCDFCARAIB
      IMPLICIT NONE

c      implicit double precision (a-h,o-z)

      include './com_18/parameter.common'
      include './com_18/annee.common'
      include './com_18/burned.common'
      include './com_18/climin0.common'
      include './com_18/climin.common'      
      include './com_18/climkop.common'
      include './com_18/co2.common'
      include './com_18/coord.common'
      include './com_18/cstpi.common'
      include './com_18/cte.common'
      include './com_18/eco.common'
      include './com_18/ecoin.common'
      include './com_18/ecopro.common'
      include './com_18/envi.common'
      include './com_18/fgr.common'
      include './com_18/fileunits.common'            
      include './com_18/gridclim.common'
      include './com_18/griddata.common'      
      include './com_18/gridin2.common'
      include './com_18/icyr.common'
      include './com_18/inidata.common'
      include './com_18/iprt.common'      
      include './com_18/landuse.common'      
      include './com_18/management.common'
      include './com_18/monthcst.common'
      include './com_18/netcdf_par.common'                  
      include './com_18/nspc.common'
      include './com_18/prt_ctrl.common'      
      include './com_18/radcst.common'
      include './com_18/smrd.common'
      include './com_18/sr_par.common'
      include './com_18/temper.common'
      include './com_18/vegfr.common'
      include './com_18/xlaic.common'
c-----------------------------------------------
c JLP ajout� pour implicit none
c
      integer iday,istatus,k,m,m1,m2
      real*4  aa,aaa,bb,bbb,elv,xltr2
c
c-----------------------------------------------

c// BEGIN
      CHARACTER(LEN=*), PARAMETER :: fn_caraib = __FILE__ 
c// END

      integer ngt,iread

      real*4 tem_a(nm),dte_a(nm),prc_a(nm),rhu_a(nm),shr_a(nm)
     &       ,wnd_a(nm),temax_a(nm),temin_a(nm) 
      real*4 tem_b(nm),dte_b(nm),prc_b(nm),rhu_b(nm),shr_b(nm),
     &       wnd_b(nm),temax_b(nm),temin_b(nm) 
      real*4 diff_t(nm),diff_d(nm),diff_p(nm),diff_r(nm),diff_s(nm),
     &       diff_w(nm)
      integer j,x
      
      integer nprt_clim,iy_past
      character*100 prtform
      
c// BEGIN
                      ! Starting indices and counters for NetCDF reads
      INTEGER, DIMENSION(3), SAVE :: istart = 0, ncount = 0
                      ! Temporary indices for searching purposes
      INTEGER :: ncpos_lon_save, ncpos_lat_save
c// END

c=======================================================================
c   reads soil characteristic and elevation
c   igrr: pixel number
c   ylongi, ylati: longitude, latitude (degrees)
c   isuni: soil unit (FAO, Zobler classification)
c   cla, sil, san: clay, silt, sand contents of soils (%)
c   elv: land elevation (m)
c   colour: soil color (0=dark, 0.5=medium, 1=clear)
c=======================================================================

      ylongi = xlg(ngt)   ! from griddata.common, initialised in read_eco,
      ylati = xlt(ngt)    ! read in from filtxt (soil texture, unit 1)
      isunit = isu(ngt)
      cla = clay(ngt)
      sil = silt(ngt)
      san = sand(ngt)
      elv = elev(ngt)
      
      if (num_ncdf.ge.1) then
        ncpos_lon = ilon4ngt(ngt)
        ncpos_lat = jlat4ngt(ngt)
      endif

      xltr2= ylati * pi180
      clati = cos(xltr2)
      if(clati .le. 1.e-20) clati = 1.e-20
      slati = sin(xltr2)


c  calculates volumetric fraction of water at saturation, field capacity
c  and wilting point for each texture class from Saxton et al.'s
c  parameterization 
c  ---------------------------------------------------------------------
      smfs = 0.332-7.251d-4*san + 0.1276*alog10(cla)
      if(cla.le.60.)then
         aa = dexp( - 4.396 - 0.0715*cla - 4.88d-4*san*san
     1        - 4.285d-5*san*san*cla ) * 100.
         bb = - 3.14-0.00222*cla*cla-3.484d-5*san*san*cla
      else
         aa = dexp( - 4.396 - 0.0715*60. - 4.88d-4*san*san
     1        - 4.285d-5*san*san*60. ) * 100.
         bb = - 3.14 - 0.00222*60.*60. - 3.484d-5*san*san*60.
      endif
      smfc = (33./aa)**(1./bb)
      smwp = (1500./aa)**(1./bb)
      acd=12.012-0.0755*san
      bcd=-3.8950+0.03671*san-0.1103*cla+8.7546d-4*cla*cla


c   patm: surface pressure (Pa)
c  ---------------------------------------------------------------------
      patm = patm0 - 11.5*elv + 5.44d-4*elv*elv

c   co2a: atmospheric partial pressure of CO2(mubar)
c  ---------------------------------------------------------------------

      co2a = pco2_rd*patm/patm0
      
      if ((nyear.eq.1).and.(iread.eq.0)) then
        do iy_past = 1, 20 
         co2_prev(iy_past) = co2a
	end do
      elseif (ngt.eq.1) then              
        do iy_past = 20, 2, -1 
         co2_prev(iy_past) = co2_prev(iy_past-1)
	end do
	co2_prev(1) = co2a
      endif
	


c   o2cl: atmospheric partial pressure of O2 (mubar)
c  ---------------------------------------------------------------------
      o2cl = 0.21*patm/100.   

c   colour: soil colour (0:dark - 1:light)
c  ---------------------------------------------------------------------
      colour = xcolor(ngt)

c   area: pixel area (m2)
c  ---------------------------------------------------------------------
      area = areapix(ngt)


c=======================================================================
c   reads monthly meteorological data 
c   tcel0    : temperature (deg.), 
c   tdiff0    : amplitude of diurnal temperature variation (deg.),
c   prc0     : precipitation (mm/mo),
c   sunhour0 : relative sunshine hour with respect to possible (0:1),
c   rhu0     : relative humidity (0:1),
c   win0     : horizontal wind speed (m s-1). 
c=======================================================================


      if (idaily_in.eq.0) then
      
       if (num_ncdf.ge.1) then

        istart = (/ ncpos_lon, ncpos_lat,  1 /)
        ncount = (/         1,         1, nm /)
	
       endif


       if(iclim_cal.eq.0) then
c~ c        read(2,*)aaa,bbb,(tcel0(m),m=1,nm)
c~ c// BEGIN
c~          istatus = NF_GET_VARA_REAL(ncid_filtema, ncvar_tema, 
c~      &                              istart, ncount, tcel0(1:nm))
c~          IF (istatus /= NF_NOERR)
c~      &     CALL HANDLE_NCERRORS(istatus, fn_caraib, (__LINE__-2))
c~ c// END
c~ c        read(3,*)aaa,bbb,(tdiff0(m),m=1,nm)
c~ c// BEGIN
c~          istatus = NF_GET_VARA_REAL(ncid_fildtaa, ncvar_dtaa, 
c~      &                              istart, ncount, temax0(1:nm))
c~          IF (istatus /= NF_NOERR)
c~      &     CALL HANDLE_NCERRORS(istatus, fn_caraib, (__LINE__-2))
c~ c// END
c~ c// BEGIN
c~          istatus = NF_GET_VARA_REAL(ncid_fildtba, ncvar_dtba, 
c~      &                              istart, ncount, temin0(1:nm))
c~          IF (istatus /= NF_NOERR)
c~      &     CALL HANDLE_NCERRORS(istatus, fn_caraib, (__LINE__-2))
c~ c// END
c~ 
c~ c        read(4,*)aaa,bbb,(prc0(m),m=1,nm)
c~ c// BEGIN
c~          istatus = NF_GET_VARA_REAL(ncid_filprca, ncvar_prca, 
c~      &                              istart, ncount, prc0(1:nm))
c~          IF (istatus /= NF_NOERR)
c~      &     CALL HANDLE_NCERRORS(istatus, fn_caraib, (__LINE__-2))
c~ c// END
c~ c        read(7,*)aaa,bbb,(sunhour0(m),m=1,nm)
c~ c        read(8,*)aaa,bbb,(rhu0(m),m=1,nm)
c~ c// BEGIN
c~          istatus = NF_GET_VARA_REAL(ncid_filshia, ncvar_shia, 
c~      &                              istart, ncount, sunhour0(1:nm))
c~          IF (istatus /= NF_NOERR)
c~      &     CALL HANDLE_NCERRORS(istatus, fn_caraib, (__LINE__-2))
c~ c// END
c~ 
c~ c// BEGIN
c~          istatus = NF_GET_VARA_REAL(ncid_filrhua, ncvar_rhua, 
c~      &                              istart, ncount, rhu0(1:nm))
c~          IF (istatus /= NF_NOERR)
c~      &     CALL HANDLE_NCERRORS(istatus, fn_caraib, (__LINE__-2))
c~ c// END
c~ 
c~ c// BEGIN
c~ c// DEL        read(9,*)aaa,bbb,(win0(m),m=1,nm)
c~          istatus = NF_GET_VARA_REAL(ncid_filwina, ncvar_wina, 
c~      &                              istart, ncount, win0(1:nm))
c~          IF (istatus /= NF_NOERR)
c~      &     CALL HANDLE_NCERRORS(istatus, fn_caraib, (__LINE__-2))
c~ c// END
c~ 
c~ c UNIT CONVERSION (monthly)
c~          do m = 1, nm
c~            tcel0(m)    = uc0_tem + uc1_tem * tcel0(m)
c~            temax0(m)   = uc0_dta + uc1_dta * temax0(m)
c~            temin0(m)   = uc0_dtb + uc1_dtb * temin0(m)
c~            prc0(m)     = uc0_prc + uc1_prc * prc0(m)
c~            sunhour0(m) = uc0_shi + uc1_shi * sunhour0(m)
c~            rhu0(m)     = uc0_rhu + uc1_rhu * rhu0(m)
c~            win0(m)     = uc0_win + uc1_win * win0(m)
c~          end do
c~   
c~ c END OF UNIT CONVERSION (monthly)

! Get monthly mean climate forcing data into the xxx0(:) arrays from
! the xxx1year(:,:) arrays and convert units
        tcel0(1:nm)    = uc0_tem + uc1_tem * tcel1year(1:nm, ngt)
        temax0(1:nm)   = uc0_dta + uc1_dta * temax1year(1:nm, ngt)
        temin0(1:nm)   = uc0_dtb + uc1_dtb * temin1year(1:nm, ngt)
        prc0(1:nm)     = uc0_prc + uc1_prc * prc1year(1:nm, ngt)
        sunhour0(1:nm) = uc0_shi + uc1_shi * sunhour1year(1:nm, ngt)
        rhu0(1:nm)     = uc0_rhu + uc1_rhu * rhu1year(1:nm, ngt)
        win0(1:nm)     = uc0_win + uc1_win * win1year(1:nm, ngt)

        do m = 1,nm
          if (idtem.eq.0) then
            tdiff0(m)= temax0(m)
	  else   
            tdiff0(m)= temax0(m) - temin0(m)
	  endif
          if (tdiff0(m).lt.0.) tdiff0(m)=0.
        end do 

      else     ! iclim_cal
       
       
c~ c        read(2,*)aaa,bbb,(tem_a(m),m=1,nm)
c~ c// BEGIN
c~         istatus = NF_GET_VARA_REAL(ncid_filtema, ncvar_tema,
c~      &                             istart, ncount, tem_a(1:nm))
c~         IF (istatus /= NF_NOERR)
c~      &    CALL HANDLE_NCERRORS(istatus, fn_caraib, (__LINE__-3))
c~ c// END
c~ c        read(3,*)aaa,bbb,(dte_a(m),m=1,nm)
c~ c// BEGIN
c~         istatus = NF_GET_VARA_REAL(ncid_fildtaa, ncvar_dtaa, 
c~      &                             istart, ncount, temax_a(1:nm))
c~         IF (istatus /= NF_NOERR)
c~      &    CALL HANDLE_NCERRORS(istatus, fn_caraib, (__LINE__-2))
c~ c// END
c~ c// BEGIN
c~         istatus = NF_GET_VARA_REAL(ncid_fildtba, ncvar_dtba, 
c~      &                             istart, ncount, temin_a(1:nm))
c~         IF (istatus /= NF_NOERR)
c~      &    CALL HANDLE_NCERRORS(istatus, fn_caraib, (__LINE__-2))
c~ c// END
c~ 
c~ c        read(4,*)aaa,bbb,(prc_a(m),m=1,nm)
c~ c// BEGIN
c~         istatus = NF_GET_VARA_REAL(ncid_filprca, ncvar_prca,
c~      &                             istart, ncount, prc_a(1:nm))
c~         IF (istatus /= NF_NOERR)
c~      &    CALL HANDLE_NCERRORS(istatus, fn_caraib, (__LINE__-3))
c~ c// END
c~ c        read(7,*)aaa,bbb,(shr_a(m),m=1,nm)
c~ c        read(8,*)aaa,bbb,(rhu_a(m),m=1,nm)
c~ c// BEGIN
c~         istatus = NF_GET_VARA_REAL(ncid_filshia, ncvar_shia,
c~      &                           istart, ncount, shr_a(1:nm))
c~         IF (istatus /= NF_NOERR)
c~      &    CALL HANDLE_NCERRORS(istatus, fn_caraib, (__LINE__-3))
c~ c// END
c~ 
c~ c// BEGIN
c~         istatus = NF_GET_VARA_REAL(ncid_filrhua, ncvar_rhua,
c~      &                             istart, ncount, rhu_a(1:nm))
c~         IF (istatus /= NF_NOERR)
c~      &    CALL HANDLE_NCERRORS(istatus, fn_caraib, (__LINE__-3))
c~ c// END
c~ 
c~ c// BEGIN
c~ c// DEL        read(9,*)aaa,bbb,(wnd_a(m),m=1,nm)
c~         istatus = NF_GET_VARA_REAL(ncid_filwina, ncvar_wina,
c~      &                             istart, ncount, wnd_a(1:nm))
c~         IF (istatus /= NF_NOERR)
c~      &    CALL HANDLE_NCERRORS(istatus, fn_caraib, (__LINE__-3))
c~ c// END
c~ 
c~ c UNIT CONVERSION (monthly)
c~         do m = 1, nm
c~           tem_a(m)   = uc0_tem + uc1_tem * tem_a(m)
c~           temax_a(m) = uc0_dta + uc1_dta * temax_a(m)
c~           temin_a(m) = uc0_dtb + uc1_dtb * temin_a(m)
c~           prc_a(m)   = uc0_prc + uc1_prc * prc_a(m)
c~           shr_a(m)   = uc0_shi + uc1_shi * shr_a(m)
c~           rhu_a(m)   = uc0_rhu + uc1_rhu * rhu_a(m)
c~           wnd_a(m)   = uc0_win + uc1_win * wnd_a(m)
c~         end do
c~   
c~ c END OF UNIT CONVERSION (monthly)

! Get monthly mean climate forcing data into the xxx_a(:) arrays from
! the xxx1year(:,:) arrays and convert units

        tem_a(1:nm)   = uc0_tem + uc1_tem * tcel1year(1:nm, ngt)
        temax_a(1:nm) = uc0_dta + uc1_dta * temax1year(1:nm, ngt)
        temin_a(1:nm) = uc0_dtb + uc1_dtb * temin1year(1:nm, ngt)
        prc_a(1:nm)   = uc0_prc + uc1_prc * prc1year(1:nm, ngt)
        shr_a(1:nm)   = uc0_shi + uc1_shi * sunhour1year(1:nm, ngt)
        rhu_a(1:nm)   = uc0_rhu + uc1_rhu * rhu1year(1:nm, ngt)
        wnd_a(1:nm)   = uc0_win + uc1_win * win1year(1:nm, ngt)


! Get monthly mean climate forcing data into the xxx_b(:) by reading
! them provisionally directly from the file
        if (incdf_tem.eq.1) then
c// BEGIN
         istatus = NF_GET_VARA_REAL(ncid_filtemb, ncvar_temb,
     &                             istart, ncount, tem_b(1:nm))
         IF (istatus /= NF_NOERR)
     &    CALL HANDLE_NCERRORS(istatus, fn_caraib, (__LINE__-3))
c// END
        else
	 read(iunit_temb,*)aaa,bbb,(tem_b(m),m=1,nm)
	endif
	
	if (incdf_dta.eq.1) then
c// BEGIN
         istatus = NF_GET_VARA_REAL(ncid_fildtab, ncvar_dtab, 
     &                             istart, ncount, temax_b(1:nm))
         IF (istatus /= NF_NOERR)
     &    CALL HANDLE_NCERRORS(istatus, fn_caraib, (__LINE__-2))
c// END
        else
         read(iunit_dtab,*)aaa,bbb,(temax_b(m),m=1,nm)
	endif
	
        if (idtem.eq.1) then
	 if (incdf_dtb.eq.1) then	
c// BEGIN
          istatus = NF_GET_VARA_REAL(ncid_fildtbb, ncvar_dtbb, 
     &                             istart, ncount, temin_b(1:nm))
          IF (istatus /= NF_NOERR)
     &     CALL HANDLE_NCERRORS(istatus, fn_caraib, (__LINE__-2))
c// END
         else
	  read(iunit_dtbb,*)aaa,bbb,(temin_b(m),m=1,nm)
	 endif
	endif

	if (incdf_prc.eq.1) then	
c// BEGIN
         istatus = NF_GET_VARA_REAL(ncid_filprcb, ncvar_prcb,
     &                             istart, ncount, prc_b(1:nm))
         IF (istatus /= NF_NOERR)
     &    CALL HANDLE_NCERRORS(istatus, fn_caraib, (__LINE__-3))
c// END
        else
         read(iunit_prcb,*)aaa,bbb,(prc_b(m),m=1,nm)
	endif

	if (incdf_shi.eq.1) then
c// BEGIN
         istatus = NF_GET_VARA_REAL(ncid_filshib, ncvar_shib,
     &                           istart, ncount, shr_b(1:nm))
         IF (istatus /= NF_NOERR)
     &    CALL HANDLE_NCERRORS(istatus, fn_caraib, (__LINE__-3))
c// END
        else
         read(iunit_shib,*)aaa,bbb,(shr_b(m),m=1,nm)
	endif

	if (incdf_rhu.eq.1) then
c// BEGIN
         istatus = NF_GET_VARA_REAL(ncid_filrhub, ncvar_rhub,
     &                             istart, ncount, rhu_b(1:nm))
         IF (istatus /= NF_NOERR)
     &    CALL HANDLE_NCERRORS(istatus, fn_caraib, (__LINE__-3))
c// END
        else
         read(iunit_rhub,*)aaa,bbb,(rhu_b(m),m=1,nm)
	endif

	if (incdf_win.eq.1) then
c// BEGIN
        istatus = NF_GET_VARA_REAL(ncid_filwinb, ncvar_winb,
     &                             istart, ncount, wnd_b(1:nm))
        IF (istatus /= NF_NOERR)
     &    CALL HANDLE_NCERRORS(istatus, fn_caraib, (__LINE__-3))
c// END
        else
         read(iunit_winb,*)aaa,bbb,(wnd_b(m),m=1,nm)
	endif

c UNIT CONVERSION (monthly)
        do m = 1, nm
          tem_b(m)   = uc0_tem + uc1_tem * tem_b(m)
          temax_b(m) = uc0_dta + uc1_dta * temax_b(m)
          temin_b(m) = uc0_dtb + uc1_dtb * temin_b(m)
          prc_b(m)   = uc0_prc + uc1_prc * prc_b(m)
          shr_b(m)   = uc0_shi + uc1_shi * shr_b(m)
          rhu_b(m)   = uc0_rhu + uc1_rhu * rhu_b(m)
          wnd_b(m)   = uc0_win + uc1_win * wnd_b(m)
        end do
  
c END OF UNIT CONVERSION (monthly)


        do m = 1,nm
          if (idtem.eq.0) then
            tdiff0(m)= temax0(m)
            dte_a(m) = temax_a(m)
            dte_b(m) = temax_b(m)
	  else   
            tdiff0(m)= temax0(m) - temin0(m)
            dte_a(m) = temax_a(m) - temin_a(m)
            dte_b(m) = temax_b(m) - temin_b(m)
	  endif
	
          if (tdiff0(m).lt.0.) tdiff0(m)=0.
          if (dte_a(m).lt.0.) dte_a(m)=0.
          if (dte_b(m).lt.0.) dte_b(m)=0.
        end do   
	      

       
        x = ibb-iaa
        j = nyear2-iaa
        
        do m = 1,nm      
          diff_t(m) = tem_b(m) - tem_a(m)
          diff_d(m) = dte_b(m) - dte_a(m)
          diff_p(m) = prc_b(m) - prc_a(m)
          diff_s(m) = shr_b(m) - shr_a(m)
          diff_r(m) = rhu_b(m) - rhu_a(m)
          diff_w(m) = wnd_b(m) - wnd_a(m)
          
          tcel0(m)    = tem_a(m) + j*(diff_t(m)/x)
          tdiff0(m)   = dte_a(m) + j*(diff_d(m)/x)
          prc0(m)     = prc_a(m) + j*(diff_p(m)/x)
          sunhour0(m) = shr_a(m) + j*(diff_s(m)/x)
          rhu0(m)     = rhu_a(m) + j*(diff_r(m)/x)
          win0(m)     = wnd_a(m) + j*(diff_w(m)/x)
        enddo  
              
        endif  ! iclim_cal
       
        do k=1,nm
          sunhour0(k)=sunhour0(k)/100.
          if (sunhour0(k).lt.0.) sunhour0(k)=0.
          if (sunhour0(k).gt.1.) sunhour0(k)=1.
        enddo
       
        do k=1,nm
          rhu0(k)=rhu0(k)/100.
          if (rhu0(k).lt.0.) rhu0(k)=0.
          if (rhu0(k).gt.1.) rhu0(k)=1.
        enddo

      else  ! i.e., if (idaily_in /= 0) then

c~ c// istart in the following will have to be changed in case daily data
c~ c// would have to be read in fomr some other starting point than the
c~ c// first day in the file.
c~ 
c~         istart = (/ ncpos_lon, ncpos_lat,  ncpos_time /)
c~         ncount = (/         1,         1, nd /)


! Load the data into the xxx(:) arrays from the xxx1year(:,:) arrays
! and convert units; sanity check and limit them.
        tcel(1:nd)  = uc0_tem + uc1_tem * tcel1year(1:nd, ngt)

        temax(1:nd) = uc0_dta + uc1_dta * temax1year(1:nd, ngt)
        temin(1:nd) = uc0_dtb + uc1_dtb * temin1year(1:nd, ngt)

        do iday = 1,nd
          if (idtem.eq.0) then
            tdiff(iday)= temax(iday)
	  else   
	    tdiff(iday)= temax(iday) - temin(iday)
	  endif
	  if (tdiff(iday).lt.0.) tdiff(iday)=0.
	enddo   

        prc(1:nd)      = uc0_prc + uc1_prc * prc1year(1:nd, ngt)

        sunhour(1:nd) = uc0_shi + uc1_shi * sunhour1year(1:nd, ngt)

        if (isol.eq.0) then
          do iday=1,nd
            sunhour(iday) = sunhour(iday)/100.
            if (sunhour(iday).lt.0.) sunhour(iday)=0.
            if (sunhour(iday).gt.1.) sunhour(iday)=1.
          enddo
        else
          do iday = 1, nd
	    fsol(iday) = sunhour(iday)
	  end do
        endif
        
        rhu(1:nd) = uc0_rhu + uc1_rhu * rhu1year(1:nd, ngt)

        do iday=1,nd
          rhu(iday)=rhu(iday)/100.
          if (rhu(iday).lt.0.1) rhu(iday)=0.1
          if (rhu(iday).gt.1.) rhu(iday)=1.
        enddo
       
        win(1:nd) = uc0_win + uc1_win * win1year(1:nd, ngt)

        do m=1,nm
          tcel0(m) = 0.
          tdiff0(m) = 0.
          prc0(m) = 0.
          if (isol.eq.0) then
            sunhour0(m) = 0.
          else
            fsol0(m) = 0.
          endif

          rhu0(m) = 0.
          win0(m) = 0.
        end do
       
        do iday = 1, nd
          m = imonth(iday) 
          tcel0(m)  = tcel0(m)  + tcel(iday)/float(mlength(m))      
          tdiff0(m) = tdiff0(m) + tdiff(iday)/float(mlength(m))
          prc0(m)   = prc0(m)   + prc(iday)
          if (isol.eq.0) then
            sunhour0(m) = sunhour0(m)+sunhour(iday)/float(mlength(m))
          else
            fsol0(m) = fsol0(m)+fsol(iday)/float(mlength(m))
          endif  
          rhu0(m)    = rhu0(m)+rhu(iday)/float(mlength(m))                
          win0(m)    = win0(m)+win(iday)/float(mlength(m))  
        end do
           
      endif

c=======================================================================
c   prints climate data if ipr_clim is not equal to 0  
c=======================================================================

      if (ipr_clim.ne.0)then
      
       if (ipr_clim.eq.1)then 
        if (iprt_tem.eq.1) then
	 write(prtform,*)'(f8.3,1x,f8.3,',nm,'(1x,f6.2))'
         write(502,prtform)ylongi,ylati,(tcel0(m),m=1,nm)
	endif
	if (iprt_dte.eq.1) then
	 write(prtform,*)'(f8.3,1x,f8.3,',nm,'(1x,f6.2))'      
         write(503,prtform)ylongi,ylati,(tdiff0(m),m=1,nm)
	endif
	if (iprt_prc.eq.1) then
	 write(prtform,*)'(f8.3,1x,f8.3,',nm,'(1x,f7.2))'      
         write(504,prtform)ylongi,ylati,(prc0(m),m=1,nm)
	endif
	if (iprt_shr.eq.1) then
	 if (isol.eq.0) then
	  write(prtform,*)'(f8.3,1x,f8.3,',nm,'(1x,f6.2))'      
          write(507,prtform)ylongi,ylati,(100.*sunhour0(m),m=1,nm)
	 else	
          write(prtform,*)'(f8.3,1x,f8.3,',nm,'(1x,f7.2))'      
          write(507,prtform)ylongi,ylati,(fsol0(m),m=1,nm)
         endif
	endif
	if (iprt_rhu.eq.1) then  
	 write(prtform,*)'(f8.3,1x,f8.3,',nm,'(1x,f6.2))'      
         write(508,prtform)ylongi,ylati,(100.*rhu0(m),m=1,nm)
	endif
	if (iprt_win.eq.1) then	
	 write(prtform,*)'(f8.3,1x,f8.3,',nm,'(1x,f6.2))'      
         write(509,prtform)ylongi,ylati,(win0(m),m=1,nm)
	endif	
       else
        if (iprt_tem.eq.1) then
	 write(prtform,*)'(f8.3,1x,f8.3,',nd,'(1x,f6.2))'      
         write(502,prtform)ylongi,ylati,(tcel(iday),iday=1,nd)
	endif
	if (iprt_dte.eq.1) then
	 write(prtform,*)'(f8.3,1x,f8.3,',nd,'(1x,f6.2))'      
         write(503,prtform)ylongi,ylati,(tdiff(iday),iday=1,nd)
	endif
	if (iprt_prc.eq.1) then
	 write(prtform,*)'(f8.3,1x,f8.3,',nd,'(1x,f7.2))'      
         write(504,prtform)ylongi,ylati,(prc(iday),iday=1,nd)
	endif
	if (iprt_shr.eq.1) then
	 if (isol.eq.0) then
	  write(prtform,*)'(f8.3,1x,f8.3,',nd,'(1x,f6.2))'      
          write(507,prtform)ylongi,ylati,(100.*sunhour(iday),iday=1,nd)
	 else	
          write(prtform,*)'(f8.3,1x,f8.3,',nd,'(1x,f7.2))'      
          write(507,prtform)ylongi,ylati,(fsol(iday),iday=1,nd)
         endif
	endif
	if (iprt_rhu.eq.1) then  
	 write(prtform,*)'(f8.3,1x,f8.3,',nd,'(1x,f6.2))'      
         write(508,prtform)ylongi,ylati,(100.*rhu(iday),iday=1,nd)
	endif
	if (iprt_win.eq.1) then	
	 write(prtform,*)'(f8.3,1x,f8.3,',nd,'(1x,f6.2))'      
         write(509,prtform)ylongi,ylati,(win(iday),iday=1,nd)
	endif	
       endif	
       	
      endif
      
c=======================================================================
c   reads management data 
c      mg_mode: type of management (1 = provide LAI and aboveground
c                                  structural carbon left after cutting)
c      mg_days: numbers of days where management is operated over the 
c               year (= management days)
c      iday_mg: day number of management days (mg_days values must be
c               provided)
c      cleft(1,*): LAI, carbon content or biomass proportion (depending 
c                  on mg_mode) of reservoir 1 left after cutting 
c                  (mg_days values must be provided)
c      cleft(2,*): aboveground carbon or biomass proportion (depending 
c                  on mg_mode) of reservoir 2 left after cutting 
c                  (mg_days values must be provided) 
c=======================================================================

      if (imanag.eq.1) read(92,*)aaa,bbb,mg_mode,mg_days
     &    ,(iday_mg(m),m=1,mg_days),(cleft_mg(1,m1),m1=1,mg_days)
     &    ,(cleft_mg(2,m2),m2=1,mg_days)

c      write(*,*)mg_mode,mg_days
c      write(*,*)(iday_mg(m),m=1,mg_days)
c      write(*,*)(cleft_mg(1,m1),m1=1,mg_days)
c      write(*,*)(cleft_mg(2,m2),m2=1,mg_days)

c=======================================================================
c   reads monthly lightning data 
c   xmflash   : flash frequency (flashes km-2 mo-1)
c=======================================================================

      if (ifire.eq.1) read(93,*)aaa,bbb,(xmflash(m),m=1,nm)      

c=======================================================================
c  Climatological means of temperature (�C) and precipitation (mm/mo)
c  used to calculate Koppen's climatic zones
c  (here taken to be equal to monthly weather)
c=======================================================================
      if (idaily_in.eq.0) then
       do m = 1, nm
         tcelkop(m)=tcel_clim(m,ngt)
         prckop(m)=prc_clim(m,ngt)
       enddo
      else
       do m = 1, nm
         tcelkop(m)=tcel0(m)
         prckop(m)=prc0(m)
       enddo      
      endif

c=======================================================================
c     soil respiration parameters
c=======================================================================

      pssat=0.01*(0.75*cla+0.625*sil+0.500*san)
      xm1=0.01*(-1.883*cla+0.140*sil+0.356*san)
      cmoxm1=(0.01*(0.73*cla+0.68*sil+0.59*san))**xm1


      return
      end subroutine read_in