c=======================================================================
c***********************************************************************
      subroutine zonepxl2(iprint)
c***********************************************************************
c=======================================================================
c Determines the geoclimatic zone corresponding to the studied region 
c (or grid element in the case of gridded data). This subroutine should
c be called for each region or grid element studied with climatological
c means of the regions as inputs
c
c  INPUTS: (1) User must supply avererage climatology of the region, 
c            common block /climkop/ must be filled prior to the call:
c            - tcelkop(nm): 12 monthly climatological means of 
c              temperature in °C
c            - prckop(nm): 12 monthly climatological means of
c                        precipitation in mm/mo
c          (2) subroutine "ctgen" must be called prior to the call to
c            "zonepxl2" to set a series of constants, including the
c            names of the 176 geoclimatic zones (vector listzone)
c          (3) iprint= 1 or 0 to print or not the number and name of
c            of the Koppen climatic zone in unit 22 (to be opened by the
c            user before the call to "zonepxl2")
c          (4) longitude and latitude of the studied pixel must be set
c            in ylongi and ylati
c 
c  OUTPUTS: The output of "zonepxl2" is returned in common /pzone/:
c           - izonepxl: geoclimatic zone number (1-176) of the 
c                       studied region.  
c           The local variable "zon" contains the name of the 
c           geoclimatic zone.
c           The same information can also be obtained as the component
c           "izonepxl" of vector listezone: 
c           - listezone(izonepxl): name of the geoclimatic zone
c           We refer to Hubert et al. (1998) for the full classification
c           of climatic zones. It is based on the following Koppen's
c           climatic zones with additional geographic subdivision. 
c-----------------------------------------------------------------------
c  A : Tropical Climates
c      Af : Tropical Rainy Climate
c      Am : Tropical Wet Climate
c      Aw : Dry Monsoon Climate
c      As : Dry Monsoon Climate
c  B : Dry Climates
c      Bw : Desert Climate 
c      Bs : Steppes Climate 
c  C : Mid-Latitude Rainy Climate
c      Cs : with dry summer
c      Cw : with dry winter
c      Cf : precipitation in all seasons
c  D : Continental Climate
c     (Ds : with dry summer)
c      Dw : with dry winter
c      Df : precipitation in all seasons
c  E : Polar Climates
c      ET : Tundra climate
c      EF : Snow climate
c=======================================================================
      implicit none
      
      include './com_18/parameter.common'
      include './com_18/climkop.common'
      include './com_18/coord.common'
      include './com_18/iprt.common'
      include './com_18/lstz.common'
      include './com_18/lstcli.common'
      include './com_18/lstreg.common'
      include './com_18/pzone.common'
c-----------------------------------------------
c JLP ajout� pour implicit none
c
      integer i,iprint,izone,m
      real*4  p12,p6
c
c-----------------------------------------------

      character*1 regpxl
      character*2 zonepixl
      character*3 climpxl
      character*8 zon

      call koppen2(climpxl)

      do i = 1, 34
         if(climpxl .eq. climatslst(i)) regpxl=reg(i)
      enddo

      call zone2(regpxl,zonepixl)

      if(zonepixl .eq. 'B2' .or.
     &   zonepixl .eq. 'B3' .or.
     &   zonepixl .eq. 'C3'      )then
c      All these grid elements belong to the northern hemisphere.

         p12 = 0.
         p6  = 0.
         do m = 1, nm
            p12 = p12 + prckop(m)
         enddo
         do m = 4, 9
            p6 = p6 + prckop(m)
         enddo
         if(p6 .ge. 0.5*p12)then
            zon = zonepixl//climpxl//'prh'
         else 
            zon = zonepixl//climpxl//'prs'
         endif
      else
         zon = zonepixl//climpxl
      endif

      izonepxl=200
      do izone = 1, nzone
         if(zon .eq. listezone(izone)) then
            izonepxl = izone
            if(iprint.eq.1)write(22,250)ylongi,ylati
     &                                 ,izonepxl,zon
            return
         endif
      enddo

250   format(2(1x,f8.3),1x,i3,1x,a8)

      return
      end subroutine zonepxl2